==> bootstrap-for-market-website-1.0.29.tgz: package/js/components/main-locale-switcher.js <==
/*! anamo/bootstrap-for-market-website v0.0.0 | © 2006-present Panagiotis Tsimpoglou. All rights reserved | bitbucket.org/anamo/bootstrap-for-market-website */

import $ from 'jquery'
import meta from '../js-initializers'
import Cookies from 'js-cookie'

if ('true' !== Cookies.get('main-ls-disclosure') &&
	0 < $('.main-locale-menu--regions-list-group a[data-suffix]').length &&
	0 === $('.main-header--account-toggle').length) {
	$.ajax({
		url: 'https://www.cloudflare.com/cdn-cgi/trace', // NOTE: was 'http://www.geoplugin.net/json.gp',
		dataType: 'text',
		cache: true,
		timeout: 2000
	}).
		done(cloudFlareData => {
			let ip = $.trim(cloudFlareData.match(/^ip=.*/gm)).substring(3)
			$.ajax({
				url: `https://json.geoiplookup.io/api/${ip}`, // NOTE: was 'http://www.geoplugin.net/json.gp',
				dataType: 'json',
				cache: true,
				timeout: 4000
			}).
				done(data => {
					if (!data) return

					let clientCode = $.trim(data.country_code),// NOTE: was $.trim(data.geoplugin_countryCode),
						clientFallbackCode = $.trim(data.continent_code)// NOTE: was $.trim(data.geoplugin_continentCode)

					let supportedRegions = {} // NOTE: {JP: "/jp", AT: "/at", BE: "/be", BG: "/bg", CY: "/cy", …}
					for (let [k, v] of Object.entries(meta.suppportedSuffixes)) {
						if (!v.flag) continue
						supportedRegions[v.flag.split('/').pop().split('.', 2).shift().toLocaleUpperCase()] = k
					}

					let currentCode = Object.keys(supportedRegions).find(key => supportedRegions[key] === meta.APP_SUFFIX),
						suggestedCode = currentCode

					if (Object.keys(supportedRegions).includes(clientCode)) {
						if (currentCode !== clientCode) suggestedCode = clientCode
					} else if (Object.keys(supportedRegions).includes(clientFallbackCode)) {
						if (currentCode !== clientFallbackCode) suggestedCode = clientFallbackCode
					} else {
						suggestedCode = '001'
					}

					if (currentCode !== suggestedCode) $(`<div class="bg-dark main-locale-switcher">
							<div class="container-fluid">
								<div class="row no-gutters pt-3 pb-4 pb-md-3 align-items-center">
									<div class="col py-3 pr-3 pr-md-4 text-white text-break">
									${meta.mainLocaleSwitcherSwitchLabels[$('html').attr('lang')]}
									</div>
									<div class="col-auto py-3 order-md-4">
										<a href="${meta.mainLocaleSwitcherCloseHref}" class="link-body-yiq">
											<svg height="34" width="34" role="img" aria-hidden="true" focusable="false" xmlns="http://www.w3.org/2000/svg" class="align-middle" viewBox="0 0 320 512">
												<path fill="currentColor" d="M193.94 256L296.5 153.44l21.15-21.15c3.12-3.12 3.12-8.19 0-11.31l-22.63-22.63c-3.12-3.12-8.19-3.12-11.31 0L160 222.06 36.29 98.34c-3.12-3.12-8.19-3.12-11.31 0L2.34 120.97c-3.12 3.12-3.12 8.19 0 11.31L126.06 256 2.34 379.71c-3.12 3.12-3.12 8.19 0 11.31l22.63 22.63c3.12 3.12 8.19 3.12 11.31 0L160 289.94 262.56 392.5l21.15 21.15c3.12 3.12 8.19 3.12 11.31 0l22.63-22.63c3.12-3.12 3.12-8.19 0-11.31L193.94 256z">
												</path>
											</svg>
										</a>
									</div>
									<div class="w-100 d-block d-md-none"></div>
									<div class="col col-md-auto order-md-2 bg-white-10 rounded px-4 mr-4 cursor-pointer main-locale-switcher--preselection" role="button">
										<div class="d-flex w-100 justify-content-between align-items-center">
											<div class="text-truncate text-white">${$(`.main-locale-menu--regions-list-group [data-suffix="${supportedRegions[suggestedCode]}"]:first`).text().toLocaleUpperCase()}</div>
											<svg height="12" width="12" role="img" aria-hidden="true" focusable="false" xmlns="http://www.w3.org/2000/svg" class="ml-3 text-muted" viewBox="0 0 448 512">
												<path fill="currentColor" d="M207.029 381.476L12.686 187.132c-9.373-9.373-9.373-24.569 0-33.941l22.667-22.667c9.357-9.357 24.522-9.375 33.901-.04L224 284.505l154.745-154.021c9.379-9.335 24.544-9.317 33.901.04l22.667 22.667c9.373 9.373 9.373 24.569 0 33.941L240.971 381.476c-9.373 9.372-24.569 9.372-33.942 0z">
												</path>
											</svg>
										</div>
									</div>
									<div class="col-auto order-md-3 mr-md-4">
										<a href="${$(`.main-locale-menu--regions-list-group [data-suffix="${supportedRegions[suggestedCode]}"]:first`).attr('href')}" class="btn btn-thick btn-primary-yiq border-0">${meta.mainLocaleSwitcherContinueBtnLabels[$('html').attr('lang')]}</a>
									</div>
								</div>
							</div>
						</div>`).insertBefore('.main-header')

				})
		})
}

$(document).

	on('click', '.main-locale-switcher--preselection', e => {
		$('html,body').animate({ scrollTop: $(document).height() - $(window).height() }, 300, 'linear', () => {
			setTimeout(() => $('.main-footer--locale-switcher,.my-locale-switcher').popover('show'), 50)
		})
	})

==> bootstrap-for-market-website-1.0.37.tgz: package/js/components/main-locale-switcher.js <==
/*! anamo/bootstrap-for-market-website v0.0.0 | © 2006-present Panagiotis Tsimpoglou. All rights reserved | bitbucket.org/anamo/bootstrap-for-market-website */

import $ from 'jquery'
import meta from '../js-initializers'
import Cookies from 'js-cookie'

if ('true' !== Cookies.get('main-ls-disclosure') &&
	0 < $('.main-locale-menu--regions-list-group a[data-suffix]').length &&
	0 === $('.main-header--account-toggle').length) {
	$.ajax({
		url: 'https://www.cloudflare.com/cdn-cgi/trace', // NOTE: was 'http://www.geoplugin.net/json.gp',
		dataType: 'text',
		cache: true,
		timeout: 2000
	}).
		done(cloudFlareData => {
			let ip = $.trim(cloudFlareData.match(/^ip=.*/gm)).substring(3)
			$.ajax({
				url: `https://json.geoiplookup.io/api/${ip}`, // NOTE: was 'http://www.geoplugin.net/json.gp',
				dataType: 'json',
				cache: true,
				timeout: 4000
			}).
				done(data => {
					if (!data) return

					let clientCode = $.trim(data.country_code),// NOTE: was $.trim(data.geoplugin_countryCode),
						clientFallbackCode = $.trim(data.continent_code)// NOTE: was $.trim(data.geoplugin_continentCode)

					let supportedRegions = {} // NOTE: {JP: "/jp", AT: "/at", BE: "/be", BG: "/bg", CY: "/cy", …}
					for (let [k, v] of Object.entries(meta.suppportedSuffixes)) {
						if (!v.flag) continue
						supportedRegions[v.flag.split('/').pop().split('.', 2).shift().toLocaleUpperCase()] = k
					}

					let currentCode = Object.keys(supportedRegions).find(key => supportedRegions[key] === meta.APP_SUFFIX),
						suggestedCode = currentCode

					if (Object.keys(supportedRegions).includes(clientCode)) {
						if (currentCode !== clientCode) suggestedCode = clientCode
					} else if (Object.keys(supportedRegions).includes(clientFallbackCode)) {
						if (currentCode !== clientFallbackCode) suggestedCode = clientFallbackCode
					} else {
						suggestedCode = '001'
					}

					if (currentCode !== suggestedCode) $(`<div class="bg-dark main-locale-switcher">
							<div class="container-fluid">
								<div class="row no-gutters pt-3 pb-4 pb-md-3 align-items-center">
									<div class="col py-3 pr-3 pr-md-4 text-white text-break">
									${meta.mainLocaleSwitcherSwitchLabels[$('html').attr('lang')]}
									</div>
									<div class="col-auto py-3 order-md-4">
										<a href="${meta.mainLocaleSwitcherCloseHref}" class="link-body-yiq">
											<svg height="34" width="34" role="img" aria-hidden="true" focusable="false" xmlns="http://www.w3.org/2000/svg" class="align-middle" viewBox="0 0 320 512">
												<path fill="currentColor" d="M193.94 256L296.5 153.44l21.15-21.15c3.12-3.12 3.12-8.19 0-11.31l-22.63-22.63c-3.12-3.12-8.19-3.12-11.31 0L160 222.06 36.29 98.34c-3.12-3.12-8.19-3.12-11.31 0L2.34 120.97c-3.12 3.12-3.12 8.19 0 11.31L126.06 256 2.34 379.71c-3.12 3.12-3.12 8.19 0 11.31l22.63 22.63c3.12 3.12 8.19 3.12 11.31 0L160 289.94 262.56 392.5l21.15 21.15c3.12 3.12 8.19 3.12 11.31 0l22.63-22.63c3.12-3.12 3.12-8.19 0-11.31L193.94 256z">
												</path>
											</svg>
										</a>
									</div>
									<div class="w-100 d-block d-md-none"></div>
									<div class="col col-md-auto order-md-2 bg-white bg-opacity-10 rounded px-4 mr-4 cursor-pointer main-locale-switcher--preselection" role="button">
										<div class="d-flex w-100 justify-content-between align-items-center">
											<div class="text-truncate text-white">${$(`.main-locale-menu--regions-list-group [data-suffix="${supportedRegions[suggestedCode]}"]:first`).text().toLocaleUpperCase()}</div>
											<svg height="12" width="12" role="img" aria-hidden="true" focusable="false" xmlns="http://www.w3.org/2000/svg" class="ml-3 text-muted" viewBox="0 0 448 512">
												<path fill="currentColor" d="M207.029 381.476L12.686 187.132c-9.373-9.373-9.373-24.569 0-33.941l22.667-22.667c9.357-9.357 24.522-9.375 33.901-.04L224 284.505l154.745-154.021c9.379-9.335 24.544-9.317 33.901.04l22.667 22.667c9.373 9.373 9.373 24.569 0 33.941L240.971 381.476c-9.373 9.372-24.569 9.372-33.942 0z">
												</path>
											</svg>
										</div>
									</div>
									<div class="col-auto order-md-3 mr-md-4">
										<a href="${$(`.main-locale-menu--regions-list-group [data-suffix="${supportedRegions[suggestedCode]}"]:first`).attr('href')}" class="btn btn-thick btn-primary-yiq border-0">${meta.mainLocaleSwitcherContinueBtnLabels[$('html').attr('lang')]}</a>
									</div>
								</div>
							</div>
						</div>`).insertBefore('.main-header')

				})
		})
}

$(document).

	on('click', '.main-locale-switcher--preselection', e => {
		$('html,body').animate({ scrollTop: $(document).height() - $(window).height() }, 300, 'linear', () => {
			setTimeout(() => $('.main-footer--locale-switcher,.my-locale-switcher').popover('show'), 50)
		})
	})
